==> 2.0.0.tar.gz: example/lib/MarketingConsentPage.dart <==
import 'package:buzz_booster_example/main.dart';
import 'package:flutter/material.dart';
import 'package:fluttertoast/fluttertoast.dart';

class MarketingConsentPage extends StatefulWidget {
  const MarketingConsentPage({
    Key? key,
  }) : super(key: key);

  @override
  State<MarketingConsentPage> createState() => _MarketingConsentPage();
}

class _MarketingConsentPage extends State<MarketingConsentPage> {
  _MarketingConsentPage();

  @override
  void initState() {
    super.initState();
    doAsyncStuff();
  }

  Future<void> doAsyncStuff() async {
    setState(() {});
    return Future.value();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text("MarketingConsent"),
        leading: IconButton(
          onPressed: () {
            Navigator.pop(context);
          },
          icon: Icon(Icons.arrow_circle_left_rounded),
        ),
      ),
      body: Container(
        height: 100,
        color: Colors.white,
        child: OutlinedButton(
        onPressed: () async {
          await buzzBooster.sendEvent("bb_marketing_consent", null);
          showToast("수신 동의");
        },
        child: const Text("수신 동의"),
      ),
      ),
    );
  }

    void showToast(String message) {
    Fluttertoast.showToast(
        msg: message,
        toastLength: Toast.LENGTH_SHORT,
        gravity: ToastGravity.CENTER,
        timeInSecForIosWeb: 1,
        backgroundColor: Colors.black45,
        textColor: Colors.white,
        fontSize: 16.0);
  }
}

==> 3.1.0.tar.gz: example/lib/MarketingConsentPage.dart <==
import 'package:buzz_booster_example/main.dart';
import 'package:flutter/material.dart';
import 'package:fluttertoast/fluttertoast.dart';

class MarketingConsentPage extends StatefulWidget {
  const MarketingConsentPage({
    Key? key,
  }) : super(key: key);

  @override
  State<MarketingConsentPage> createState() => _MarketingConsentPage();
}

class _MarketingConsentPage extends State<MarketingConsentPage> {
  _MarketingConsentPage();

  @override
  void initState() {
    super.initState();
    doAsyncStuff();
  }

  Future<void> doAsyncStuff() async {
    setState(() {});
    return Future.value();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text("MarketingConsent"),
        leading: IconButton(
          onPressed: () {
            Navigator.pop(context);
          },
          icon: Icon(Icons.arrow_circle_left_rounded),
        ),
      ),
      body: Container(
        height: 100,
        color: Colors.white,
        child: OutlinedButton(
        onPressed: () async {
          await buzzBooster.sendEvent("bb_opt_in_marketing", null);
          showToast("수신 동의");
        },
        child: const Text("수신 동의"),
      ),
      ),
    );
  }

    void showToast(String message) {
    Fluttertoast.showToast(
        msg: message,
        toastLength: Toast.LENGTH_SHORT,
        gravity: ToastGravity.CENTER,
        timeInSecForIosWeb: 1,
        backgroundColor: Colors.black45,
        textColor: Colors.white,
        fontSize: 16.0);
  }
}
